Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Helm ¶
type Helm struct {
FS vfs.FS
RelativePath string
DestinationDir string
ValuesResolver helmValuesResolver
Logger log.Logger
}
type Manager ¶
type Manager struct {
// contains filtered or unexported fields
}
func (*Manager) ConfigureComponents ¶
func (m *Manager) ConfigureComponents(ctx context.Context, conf *image.Configuration, output Output) (rm *resolver.ResolvedManifest, err error)
ConfigureComponents configures the components defined in the provided configuration and returns the resolved release manifest from said configuration.
type Opts ¶
type Opts func(m *Manager)
func WithDownloadFunc ¶
func WithDownloadFunc(d downloadFunc) Opts
func WithManifestResolver ¶
func WithManifestResolver(r releaseManifestResolver) Opts
func WithUnpackFunc ¶
func WithUnpackFunc(u unpackFunc) Opts
type Output ¶
type Output struct {
RootPath string
// ConfigPath is only populated if configuration (incl. network, catalyst and custom scripts)
// is requested separately. Note that extensions are *always* part of the RootPath instead.
ConfigPath string
}
func (Output) CatalystConfigDir ¶
func (Output) ExtractedFilesStoreDir ¶
func (Output) FirstbootConfigDir ¶
func (Output) ISOStoreDir ¶
func (Output) OverlaysDir ¶
func (Output) ReleaseManifestsStoreDir ¶
type SchemaVersion ¶
type SchemaVersion string
const SchemaV0 SchemaVersion = "v0"
func LoadSchemaVersion ¶
func LoadSchemaVersion(f vfs.FS, configDir string) (SchemaVersion, error)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.