fstab

package
v3.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 1, 2026 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

const File = "/etc/fstab"

Variables

This section is empty.

Functions

func Update

func Update(s *sys.System, fstabFile string, oldLines, newLines []Line) (err error)

Update updates the given fstab file by replacing each oldLine with its newLine.

func Write

func Write(s *sys.System, fstabFile string, fstabLines []Line) (err error)

Write writes an fstab file at the given location including the given fstab lines

Types

type Line

type Line struct {
	Device     string
	MountPoint string
	FileSystem string
	Options    []string
	DumpFreq   int
	FsckOrder  int
}

Jump to