install

package
v3.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 1, 2026 License: Apache-2.0 Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsLiveMedia

func IsLiveMedia(s *sys.System) bool

IsLiveMedia returns true if the current host is a live media

func IsRecovery

func IsRecovery(s *sys.System) bool

IsRecovery returns true if the current host is booted from an elemental recovery system

Types

type Installer

type Installer struct {
	// contains filtered or unexported fields
}

func New

func New(ctx context.Context, s *sys.System, opts ...Option) *Installer

func (Installer) Install

func (i Installer) Install(d *deployment.Deployment) (err error)

func (Installer) Reset

func (i Installer) Reset(d *deployment.Deployment) (err error)

type Option

type Option func(*Installer)

func WithBootloader

func WithBootloader(b bootloader.Bootloader) Option

func WithUnpackOpts

func WithUnpackOpts(opts ...unpack.Opt) Option

func WithUpgrader

func WithUpgrader(u upgrade.Interface) Option

Jump to