Documentation
¶
Index ¶
- Constants
- func ConfigName(path string) string
- type Metadata
- type Snapper
- func (sn Snapper) Cleanup(root string, maxSnaps int) error
- func (sn Snapper) ConfigureRoot(snapshotPath string, maxSnapshots int) error
- func (sn Snapper) CreateConfig(root, volumePath string) error
- func (sn Snapper) CreateSnapshot(root string, config string, base int, rw bool, description string, ...) (int, error)
- func (sn Snapper) DeleteByPath(path string) error
- func (sn Snapper) FirstRootSnapshot(root string, metadata Metadata) (int, error)
- func (sn Snapper) InitRootVolumes(root string) error
- func (sn Snapper) ListSnapshots(root string, config string) (Snapshots, error)
- func (sn Snapper) SetDefault(root string, id int, metadata Metadata) error
- func (sn Snapper) SetPermissions(root string, id int, rw bool) error
- func (sn Snapper) Status(root, config, output string, num1, num2 int) error
- type Snapshot
- type Snapshots
Constants ¶
const ( SnapshotsPath = ".snapshots" Installer = "/usr/lib/snapper/installation-helper" )
Variables ¶
This section is empty.
Functions ¶
func ConfigName ¶
Types ¶
type Snapper ¶
type Snapper struct {
// contains filtered or unexported fields
}
func (Snapper) ConfigureRoot ¶
ConfigureRoot sets the 'root' configuration for snapper
func (Snapper) CreateConfig ¶
func (Snapper) CreateSnapshot ¶
func (sn Snapper) CreateSnapshot(root string, config string, base int, rw bool, description string, metadata Metadata) (int, error)
CreateSnapshot creates a new snapper snapshot by calling "snapper create"
func (Snapper) DeleteByPath ¶
DeleteByPath removes the given snapshot path including any nested RO subvolume
func (Snapper) FirstRootSnapshot ¶
func (Snapper) InitRootVolumes ¶
func (Snapper) ListSnapshots ¶
func (Snapper) SetDefault ¶
func (Snapper) SetPermissions ¶
Click to show internal directories.
Click to hide internal directories.